// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
// SPDX-License-Identifier: BSD-3-Clause

// Object factories should never have deprecation warnings.
// NOLINTNEXTLINE(modernize-macro-to-enum)
#define VTK_DEPRECATION_LEVEL 0

#include "vtkRenderingVRObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkOpenGLAvatar.h"


VTK_ABI_NAMESPACE_BEGIN

vtkStandardNewMacro(vtkRenderingVRObjectFactory);

// Now create the functions to create overrides with.
VTK_CREATE_CREATE_FUNCTION(vtkOpenGLAvatar)


vtkRenderingVRObjectFactory::vtkRenderingVRObjectFactory()
{
this->RegisterOverride("vtkAvatar", "vtkOpenGLAvatar", "Override for VTK::RenderingVR module", 1, vtkObjectFactoryCreatevtkOpenGLAvatar);

}

const char * vtkRenderingVRObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkRenderingVRObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkRenderingVRCount = 0;

VTKRENDERINGVR_EXPORT void vtkRenderingVR_AutoInit_Construct()
{
  if(++vtkRenderingVRCount == 1)
  {


    vtkRenderingVRObjectFactory* factory = vtkRenderingVRObjectFactory::New();
    if (factory)
    {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
    }
  }
}
VTK_ABI_NAMESPACE_END
